# Istari Digital Client

The `istari-digital-client` library is a client SDK for interacting with the [Istari Digital platform](www.istaridigital.com).

- **Install:** `pip install istari-digital-client`
- **Documentation and Usage:** Please see [docs.istaridigital.com](docs.istaridigital.com).
- **Supported Versions:** This library supports Python 3.10, 3.11, 3.12, and 3.13
- **License:** This library is released under an MIT license with the following clarification:

> No license is hereby implied or granted to any patent or patent application relating to the Istari Digital platform itself. The list of patents applicable to the Istari Digital platform may be found at istaridigital.com/patent-list.

See the [contributing doc](./CONTRIBUTING.md) for additional info.
